Clazz.declarePackage("JS");
Clazz.declareInterface(JS, "SwingController");
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
